@@ -30,6 +30,8 @@ class ConfigChecker:
         Path(join(dirname(__file__), 'config_checkers/xlsxwriter_workbook__set_properties.json')),
         Path(join(dirname(__file__), 'config_checkers/xlsxwriter_worksheet__freeze_panes.json')),
         Path(join(dirname(__file__), 'config_checkers/xlsxwriter_worksheet__set_column.json')),
+        Path(join(dirname(__file__), 'config_checkers/xlsxwriter_worksheet__set_row.json')),
+        Path(join(dirname(__file__), 'config_checkers/xlsxwriter_workbook__options.json')),
     ]
 
     # The Validator instance which is used to later validate json configurations
