@@ -38,6 +38,7 @@ class ExcelDashboarder:
     const_str__config_label__str_ws_freeze_panes: str = "worksheet.freeze_panes"
 
     const_str__config_label__str_wb_set_properties: str = "workbook.set_properties"
+    const_str__config_label__str_wb_options: str = "workbook.options"
 
     const_str__config_label__str_ws_set_column: str = "worksheet.set_column"
     const_str__config_label__ws_set_column__cell_format__as_dict: str = "cell_format"
@@ -288,7 +289,8 @@ class ExcelDashboarder:
         # We instantiate the excel
         xls_the_writer: ExcelWriter = ExcelWriter(
             path=p_output_file_path,
-            engine='xlsxwriter'
+            engine='xlsxwriter',
+            engine_kwargs={"options": dict_config.get(self.const_str__config_label__str_wb_options, {})}
         )
         wb_the_workbook: Workbook = xls_the_writer.book
 
